@@ -9,7 +9,7 @@ TYPE_USERDEFINED = 1
 
 def dumps(C):
     dicts = {}
-    m = __import__(C.__module__, {}, {})
+    m = module_husky.loads(C.__module__)
     if not module_husky.is_userdefined(m):
         return wrap.dumps((TYPE_NON_USERDEFINED, C.__name__, m))
     for k,v in vars(C).iteritems():
