@@ -12,7 +12,12 @@ def dumps(m):
     return m.__name__
 
 def loads(b):
-    return __import__(b, {}, {}, [], -1)
+    if "." in b:
+        from_m, _, m = b.rpartition(".")
+        _temp = __import__(from_m, {}, {}, [m], -1)
+        return getattr(_temp, m)
+    else:
+        return __import__(b, {}, {}, [], -1)
 
 def is_userdefined(m):
     if not hasattr(m, "__file__"):
@@ -22,4 +27,4 @@ def is_userdefined(m):
 
 if __name__ == '__main__':
     for l in  NON_USERDEFINED_PATHES:
-        print l
\ No newline at end of file
+        print l
